##
# chanstatus.tcl version 1.0 By TS (tsukikosagi@ntlworld.com)
##
#
# This script gives a simple proc for dealing with channel status's
# such as oping, deop ...
##
# Example's
##
# chanstatus op #mychannel myfriend
#   => *** #mychannel mode [+o myfriend] By mybot
# chanstatus remove #mychannel myfriend
#   => *** #mychannel mode [-o myfriend] By mybot
# chanstatus get #mychannel myfrined
#   => 0
##
# Info
##
# when you use 'chanstatus get ?channel? ?nick?
# it will return the following:
#
#  "o" = ?nick? is opped on ?channel?
#  "v" = ?nick? is voiced on ?channel?
#  "h" = ?nick? is halfoped on ?channel?
#  "0" = ?nick? is a normal user on ?channel?
#
# the following can be used as 'status'
#
#  "op"       = will op ?nick? on ?channel?
#  "halfop"   = will halfop ?nick? on ?channel?
#  "voice"    = will voice ?nick? on ?channel?
#  "deop"     = will deop ?nick? on ?channel?
#  "dehalfop" = will dehalfop ?nick? on ?channel?
#  "devoice"  = will devoice ?nick? on ?channel?
#
##
# Syntax
##
# chanstatus ?status/get/remove? ?channel? ?nick?
##
# Returns
## 
# nothing or the channel mode of ?nick? if 'get' is used
##

proc chanstatus {args} {
 set what [lindex $args 0]
  set chan [lindex $args 1]
   set nick [lindex $args 2]
    switch $what {
     "op" {putquick "MODE $chan +o $nick"}
      "halfop" {putquick "MODE $chan +h $nick"}
       "voice" {putquick "MODE $chan +v $nick"}
        "deop" {putquick "MODE $chan -o $nick"}
         "dehalfop" {putquick "MODE $chan -h $nick"}
          "devoice" {putquick "MODE $chan -v $nick"}
           "remove" {
                     set mode [chanstatus get $chan $nick] 
                      putquick "MODE $chan -$mode $nick"
                       }
            "get" {
             if {[isop $nick $chan]} {set mode "o"}
              if {[ishalfop $nick $chan]} {set mode "h"}
               if {[isvoice $nick $chan]} {set mode "v"}
                if {![info exsist mode]} {set mode "0"}
                return $mode
                 }
 }
}

putlog "loaded chanstatus.tcl version 1.0 By TS"